package info.aspirecn.cloud.yysj.dao.es;

import com.alibaba.fastjson.JSON;
import info.aspirecn.cloud.yysj.config.IndexConfig;
import info.aspirecn.cloud.yysj.model.entity.GatewaySecondLog;
import info.aspirecn.cloud.yysj.model.entity.GatewaySecondLogList;
import lombok.SneakyThrows;
import org.elasticsearch.action.search.SearchRequest;
import org.elasticsearch.action.search.SearchResponse;
import org.elasticsearch.client.RequestOptions;
import org.elasticsearch.client.RestHighLevelClient;
import org.elasticsearch.index.query.QueryBuilders;
import org.elasticsearch.rest.RestStatus;
import org.elasticsearch.search.SearchHit;
import org.elasticsearch.search.SearchHits;
import org.elasticsearch.search.builder.SearchSourceBuilder;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Repository;
import java.io.IOException;
import java.util.ArrayList;
import java.util.List;

/**
 * ElasticSearch 云验数据平台子订单索引查询
 *
 * @author dingliqiang
 */
@Repository
public class YysjGatewaySecondIndex {

    @Autowired
    private IndexConfig indexConfig;

    @Autowired
    private RestHighLevelClient restHighLevelClient;

    /**
     * 获取主订单的全部子订单数据
     *
     * @param orderId  主订单ID
     * @return 异常效验统计结果
     */
    @SneakyThrows(IOException.class)
    public GatewaySecondLogList getSecondLogList(String orderId) {
        // 设置返回结果
        List<GatewaySecondLog> gatewaySecondLogList = new ArrayList<>();
        // 创建 Bool 查询构建器
        SearchSourceBuilder searchSourceBuilder = new SearchSourceBuilder();
        searchSourceBuilder.size(100);
        searchSourceBuilder.query(QueryBuilders.boolQuery().must(QueryBuilders.termQuery("MG-TotalTraceId.keyword", orderId)));
        // 创建查询请求对象，将查询对象配置到其中
        SearchRequest request = new SearchRequest(indexConfig.getIndexYysjSecond()).source(searchSourceBuilder);
        // 执行请求
        SearchResponse response = restHighLevelClient.search(request, RequestOptions.DEFAULT);
        if (!RestStatus.OK.equals(response.status()) || response.getAggregations() == null) {
            SearchHits hits = response.getHits();
            for (SearchHit hit : hits) {
                // 将 JSON 转换成对象
                GatewaySecondLog secondLog = JSON.parseObject(hit.getSourceAsString(), GatewaySecondLog.class);
                // 加入到对象集合
                gatewaySecondLogList.add(secondLog);
            }
        }
        return new GatewaySecondLogList().setGatewaySecondLogs(gatewaySecondLogList).setTotal(response.getHits().totalHits);
    }

}
